import QtQuick 1.1
import com.nokia.meego 1.1
import "./controls"

Page {
	id: settingsPage
	tools: settingsTools
	orientationLock: PageOrientation.LockPortrait
	//anchors.margins: rootWindow.pageMargin
	property int currTypeSys: 1
	property string currLang: "EN"
	PageHeader {
		id: headerP
		text: qsTr("Settings")
	}

	ToolBarLayout {
		id: settingsTools

		ToolButtonRow {
			ToolButton {
				text: qsTr("Apply");
				onClicked: { save(); }
			}
			ToolButton {
				text: qsTr("Cancel");
				onClicked: { pageStack.pop(); }
			}
		}
	}

	Menu {
		id: systypeMenu

		MenuLayout {
			MenuItem {
				text: qsTr("OpenMode kernel")
				onClicked: {
					settingsPage.currTypeSys=1;
					systypeButt.text=qsTr("OpenMode kernel");
				}
			}
			MenuItem {
				text: qsTr("Aegis-hack + opensudo")
				onClicked: {
					settingsPage.currTypeSys=2;
					systypeButt.text=qsTr("Aegis-hack + opensudo");
				}
			}
		}
	}

	Menu {
		id: langMenu

		MenuLayout {
			MenuItem {
				text: qsTr("English")
				onClicked: {
					settingsPage.currLang="EN";
					langButt.text=qsTr("English");
				}
			}
			MenuItem {
				text: qsTr("Russian")
				onClicked: {
					settingsPage.currLang="RU";
					langButt.text=qsTr("Russian");
				}
			}
		}
	}

	function gen_sett(enabled){
		if (enabled){
			servBox.checked=false;
			timeBox.checked=false;
			expBox.checked=false;
		}
		generalRect.visible=enabled;
	}

	function serv_sett(enabled){
		if (enabled){
			generalBox.checked=false;
			timeBox.checked=false;
			expBox.checked=false;
		}
		servRect.visible=enabled;
	}
	function time_sett(enabled){
		if (enabled){
			generalBox.checked=false;
			servBox.checked=false;
			expBox.checked=false;
		}
		timeRect.visible=enabled;
	}
	function exp_sett(enabled){
		if (enabled){
			generalBox.checked=false;
			servBox.checked=false;
			timeBox.checked=false;
		}
		expRect.visible=enabled;
	}

	Flickable {

		id: flickable
		anchors.top: headerP.bottom
		anchors.left: parent.left
		anchors.right: parent.right
		anchors.bottom: parent.bottom
		contentHeight: colEl.childrenRect.height+50
		flickableDirection: Flickable.VerticalFlick

		Column
		{
			id: colEl
			property int marginLR: 40
			property string colorRect: "#d0d4d5" //"#d0d4d5" //"#1281DD" "#9EA2A3"
			property string colorLine: "black" //"black"//"#067dec"
			property int borderWidth: 2
			property int spaceCol: 8
			property int marginSwitch: 20
			anchors.top: parent.top
			anchors.topMargin: 20
			anchors.left: parent.left
			anchors.right: parent.right
			spacing : 5
			//----------------------------------------------------------------
			SwitchBox{
				id: generalBox
				anchors.leftMargin: colEl.marginSwitch
				anchors.left: parent.left
				anchors.right: parent.right
				text: qsTr("General settings")
				onClicked: {
					gen_sett(generalBox.checked);

				}
			}
			Rectangle{
				id: generalRect
				color: colEl.colorRect
				border.color: colEl.colorLine
				border.width: colEl.borderWidth
				anchors.left: parent.left
				anchors.right: parent.right

				height: generalCol.childrenRect.height+colEl.marginLR

				Column
				{
					id: generalCol
					spacing : colEl.spaceCol
					anchors.top: parent.top
					anchors.topMargin: colEl.marginLR/2
					anchors.left: parent.left
					anchors.leftMargin: colEl.marginLR
					anchors.right: parent.right
					anchors.rightMargin: colEl.marginLR

					Label {
						id: labelLang
						text: qsTr("Language:")
						anchors.left: parent.left
					}

					Button{
						id: langButt
						text: qsTr("English")
						anchors.left: parent.left
						anchors.right: parent.right
						onClicked: {
							langMenu.open();
						}
					}


					Label {
						id: labelTypeSys
						text: qsTr("Type update system time:")
						anchors.left: parent.left
					}

					Button{
						id: systypeButt
						text: qsTr("OpenMode kernel")
						anchors.left: parent.left
						anchors.right: parent.right
						onClicked: {
							systypeMenu.open();
						}
					}


					Label {
						id: labelPassw
						text: qsTr("Root password:")
						anchors.left: parent.left
					}

					TextField {
						id: textFieldPassw
						echoMode: TextInput.Password
						anchors.left: parent.left
						anchors.right: parent.right
					}
				}
			}
			//--------------------------------------------------------------------
			SwitchBox{
				id: servBox
				anchors.leftMargin: colEl.marginSwitch
				anchors.left: parent.left
				anchors.right: parent.right
				text: qsTr("NTP server settings")
				onClicked: {
					serv_sett(servBox.checked);
				}
			}

			Rectangle{
				id: servRect
				color: colEl.colorRect
				border.color: colEl.colorLine
				border.width: colEl.borderWidth
				anchors.left: parent.left
				anchors.right: parent.right

				height: servCol.childrenRect.height+colEl.marginLR

				Column
				{
					id: servCol
					anchors.top: parent.top
					anchors.topMargin: colEl.marginLR/2
					spacing : colEl.spaceCol
					anchors.left: parent.left
					anchors.leftMargin: colEl.marginLR
					anchors.right: parent.right
					anchors.rightMargin: colEl.marginLR

					Label {
						id: labelServIP
						text: qsTr("Time Server IP Address:")
						anchors.left: parent.left
					}

					TextField {
						id: textFieldServIP
						anchors.left: parent.left
						anchors.right: parent.right
					}

					Label {
						id: labelServPort
						anchors.left: parent.left

						text: qsTr("Time Server Port:")
					}
					TextField {
						id: textFieldServPort
						//errorHighlight: !acceptableInput
						validator: IntValidator{bottom: 1; top: 999999;}

						anchors.left: parent.left
						anchors.right: parent.right
					}
				}
			}
			//-------------------------------------------------------------------------
			SwitchBox{
				id: timeBox
				anchors.leftMargin: colEl.marginSwitch
				anchors.left: parent.left
				anchors.right: parent.right
				text: qsTr("Time diff settings")
				onClicked: {
					time_sett(timeBox.checked);
				}
			}

			Rectangle{
				id: timeRect
				color: colEl.colorRect
				border.color: colEl.colorLine
				border.width: colEl.borderWidth
				anchors.left: parent.left
				anchors.right: parent.right

				height: timeCol.childrenRect.height+colEl.marginLR

				Column
				{
					id: timeCol
					anchors.top: parent.top
					anchors.topMargin: colEl.marginLR/2
					spacing : colEl.spaceCol
					anchors.left: parent.left
					anchors.leftMargin: colEl.marginLR
					anchors.right: parent.right
					anchors.rightMargin: colEl.marginLR

					Label {
						id: labelAddHours
						anchors.left: parent.left
						text: qsTr("Add hours to time of server:")
					}

					UpDownEditor
					{
						id: addHoursUDE
						anchors.left: parent.left
						anchors.right: parent.right
						minValue: -12
						maxValue: 12
						currValue: 0

					}

					Label {
						id: labelAddMins
						anchors.left: parent.left
						text: qsTr("Add mins to time of server:")
					}

					UpDownEditor
					{
						id: addMinsUDE
						anchors.left: parent.left
						anchors.right: parent.right
						minValue: -59
						maxValue: 59
						currValue: 0

					}
					CheckBox {
						id: useUtcCB
						anchors.left: parent.left

						text: qsTr("Used system UTC differents")
						checked: true
					}
				}
			}
			//-------------------------------------------------------------------------
			SwitchBox{
				id: expBox
				anchors.leftMargin: colEl.marginSwitch
				anchors.left: parent.left
				anchors.right: parent.right
				text: qsTr("Experimental settings")
				onClicked: {
					exp_sett(expBox.checked);
				}
			}

			Rectangle{
				id: expRect
				color: colEl.colorRect
				border.color: colEl.colorLine
				border.width: colEl.borderWidth
				anchors.left: parent.left
				anchors.right: parent.right

				height: expCol.childrenRect.height+colEl.marginLR

				Column
				{
					id: expCol
					anchors.top: parent.top
					anchors.topMargin: colEl.marginLR/2
					spacing : colEl.spaceCol
					anchors.left: parent.left
					anchors.leftMargin: colEl.marginLR
					anchors.right: parent.right
					anchors.rightMargin: colEl.marginLR

					CheckBox {
						id: useChkNetCB
						anchors.left: parent.left

						text: qsTr("Show connections")
						checked: true
						onClicked: {
							textHttpChk.visible=useChkNetCB.checked;
							labelHttpChk.visible=useChkNetCB.checked;
						}
					}

					Label {
						id: labelHttpChk
						text: qsTr("Request for show connections:")
						anchors.left: parent.left
					}

					TextField {
						id: textHttpChk
						anchors.left: parent.left
						anchors.right: parent.right
					}
					CheckBox {
						id: useDebugCB
						anchors.left: parent.left

						text: qsTr("Show debug messages in console")
						checked: false

					}
				}
			}
			//-------------------------------------------------------------------------
		}

	}
	
	ScrollDecorator {
		flickableItem: flickable
	}

	function save() {
		objParams.sltSetParam("PSWD",textFieldPassw.text);
		objParams.sltSetParam("TIME_HOST",textFieldServIP.text);
		objParams.sltSetParam("TIME_PORT",textFieldServPort.text);
		objParams.sltSetParam("HOURS_DIFF",addHoursUDE.currValue);
		objParams.sltSetParam("MIN_DIFF",addMinsUDE.currValue);
		objParams.sltSetParam("USE_SYS_UTC_DIFF",useUtcCB.checked);

		objParams.sltSetParam("TYPE_TIME_CHANGE",settingsPage.currTypeSys);
		objParams.sltSetParam("LANG",settingsPage.currLang);

		objParams.sltSetParam("SHOW_NETWORKS",useChkNetCB.checked);
		objParams.sltSetParam("URL_FOR_CHK",textHttpChk.text);

		objParams.sltSetParam("USE_DEBUG",useDebugCB.checked);


		objParams.sltSetDebugActive(useDebugCB.checked);
		objLocale.sltSetDebugActive(useDebugCB.checked);
		objNtpDate.sltSetDebugActive(useDebugCB.checked);


		objParams.sltSaveAll();

		objLocale.sltChangeLang(settingsPage.currLang);
		//objParams.sltDebugParams();
		pageStack.pop();
	}
	
	Component.onCompleted: {
		textFieldPassw.text = objParams.getParam("PSWD");
		textFieldServIP.text = objParams.getParam("TIME_HOST");
		textFieldServPort.text = objParams.getParam("TIME_PORT");
		addHoursUDE.currValue = objParams.getParam("HOURS_DIFF");
		addMinsUDE.currValue = objParams.getParam("MIN_DIFF");
		useUtcCB.checked = objParams.getParam("USE_SYS_UTC_DIFF");
		settingsPage.currTypeSys = objParams.getParam("TYPE_TIME_CHANGE");
		settingsPage.currLang = objParams.getParam("LANG");

		useChkNetCB.checked = objParams.getParam("SHOW_NETWORKS");
		useDebugCB.checked = objParams.getParam("USE_DEBUG");
		textHttpChk.visible=useChkNetCB.checked;
		labelHttpChk.visible=useChkNetCB.checked;

		textHttpChk.text = objParams.getParam("URL_FOR_CHK");


		if (settingsPage.currTypeSys==2){
			systypeButt.text=qsTr("Aegis-hack + opensudo");
		}
		else {
			systypeButt.text=qsTr("OpenMode kernel");
		}

		if (settingsPage.currLang == "EN"){
			langButt.text=qsTr("English");
		} else {
			langButt.text=qsTr("Russian");
		}

		generalBox.checked=true;
		serv_sett(false);
		time_sett(false);
		exp_sett(false);
		//objParams.sltDebugParams();
	}
}     
